@@ -1,4 +1,4 @@
 library(testthat)
 library(Quandl)
 
-test_package("Quandl")
\ No newline at end of file
+# test_package("Quandl")
\ No newline at end of file
